# Guide for new contributors

Thanks for contributing to `PyDAP`! There are many ways to contribute, and here we
provide steps to cover some of the most straightforward ways to contribute.

```{tableofcontents}

```
